==> foundry_platform_sdk-0.19.0.tar.gz: foundry_platform_sdk-0.19.0/foundry/v1/datasets/models/_list_branches_response.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Optional
from typing import cast

from pydantic import BaseModel
from pydantic import Field

from foundry.v1.core.models._page_token import PageToken
from foundry.v1.datasets.models._branch import Branch
from foundry.v1.datasets.models._list_branches_response_dict import ListBranchesResponseDict  # NOQA


class ListBranchesResponse(BaseModel):
    """ListBranchesResponse"""

    next_page_token: Optional[PageToken] = Field(alias="nextPageToken", default=None)

    data: List[Branch]
    """The list of branches in the current page."""

    model_config = {"extra": "allow"}

    def to_dict(self) -> ListBranchesResponseDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(ListBranchesResponseDict, self.model_dump(by_alias=True, exclude_unset=True))

==> foundry_platform_sdk-0.74.0.tar.gz: foundry_platform_sdk-0.74.0/foundry/v1/datasets/models/_list_branches_response.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Optional
from typing import cast

import pydantic

from foundry.v1.core.models._page_token import PageToken
from foundry.v1.datasets.models._branch import Branch
from foundry.v1.datasets.models._list_branches_response_dict import ListBranchesResponseDict  # NOQA


class ListBranchesResponse(pydantic.BaseModel):
    """ListBranchesResponse"""

    next_page_token: Optional[PageToken] = pydantic.Field(alias=str("nextPageToken"), default=None)  # type: ignore[literal-required]

    data: List[Branch]

    """The list of branches in the current page."""

    model_config = {"extra": "allow", "populate_by_name": True}

    def to_dict(self) -> ListBranchesResponseDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(ListBranchesResponseDict, self.model_dump(by_alias=True, exclude_unset=True))
